Skip to content

gpg ​

GPG settings.

Type: attribute set of (submodule)

Default: { }

gpg.allowedSigners ​

File used for SSH signature verification.

Unless gpg.format is set to ssh, this will not have any effect.

INFO

When unset, GitKraken will use the global git configuration value.

Scope: Profile

Type: null or absolute path

Default: null

gpg.format ​

Format to use for commit signing.

Scope: Profile

Type: constrained string

Valid values:

  • openpgp
  • ssh

Default: openpgp

gpg.package ​

Package to use for commit signing.

When unset, the selected package defaults to:

Scope: Profile

Type: null or package

Default: if gpg.format == "openpgp" then pkgs.gnupg else pkgs.openssh

gpg.program ​

Binary to use for commit signing.

This is useful if the gpg.package exposes multiple programs and the one you wish to use for commit signing is not the default one.

When unset, the selected program defaults to:

WARNING

Make sure that the selected program is exposed by the gpg.package, since NixKraken will not validate it.

Scope: Profile

Type: null or string

Default: null

Example: bin/ssh-keygen

gpg.signCommits ​

Enable commit signature.

Scope: Profile

Type: null or boolean

Default: config.programs.git.signing.signByDefault

gpg.signTags ​

Enable tag signature.

Scope: Profile

Type: null or boolean

Default: config.programs.git.signing.signByDefault

gpg.signingKey ​

Private key to use for commit signing.

When gpg.format is set to openpgp, this is the identifier of the GPG key used for signing.

When gpg.format is set to ssh, this is the path to the SSH private key used for signing.

Scope: Profile

Type: null or string or absolute path

Default: config.programs.git.signing.key

Example: EC6624FA72B9487E

Released under the MIT License