Skip to content

graph ​

Commit graph settings.

Type: attribute set of (submodule)

Default: { }

graph.compact ​

Enable compact graph columns.

Scope: Profile

Type: boolean

Default: false

graph.highlightRows ​

Highlight associated rows when hovering over a branch.

Scope: Profile

Type: boolean

Default: true

graph.lazy ​

Enable commits lazy loading.

INFO

Additional commits will be loaded when reaching the earliest commit in the graph.

Scope: Global

Type: boolean

Default: true

graph.maxCommits ​

Maximum number of commits to show in the commit graph. Minimum value is 500.

INFO

Lower counts may help improve performance.

Scope: Global

Type: null or (positive integer, meaning >0)

Default: 2000

graph.showAll ​

Always show all commits in repository.

WARNING

This setting may cause performance issue with large repositories (like nixpkgs).

Scope: Global

Type: boolean

Default: false

graph.showAuthor ​

Show commit author.

Scope: Profile

Type: boolean

Default: false

graph.showDatetime ​

Show commit date/time.

Scope: Profile

Type: boolean

Default: false

graph.showDesc ​

Show commit description.

Scope: Profile

Type: null or constrained string

Valid values:

  • always
  • hover
  • never

Default: always

graph.showGhostRefs ​

Show ghost branch/tag when hovering over or selecting a commit.

Scope: Profile

Type: boolean

Default: true

graph.showGraph ​

Show commit tree.

Scope: Profile

Type: boolean

Default: true

graph.showMessage ​

Show commit message.

Scope: Profile

Type: boolean

Default: true

graph.showRefs ​

Show branches and tags.

Scope: Profile

Type: boolean

Default: true

graph.showSHA ​

Show commit SHA.

Scope: Profile

Type: boolean

Default: false

graph.useAuthorInitials ​

Use author initials instead of avatars.

Scope: Profile

Type: boolean

Default: false

graph.useGenericRemoteIcon ​

Use generic remote icon instead of hosting service icon.

Scope: Profile

Type: boolean

Default: false

Released under the MIT License